@@ -7,14 +7,17 @@ from typing import List, Iterable, Optional, Union, Iterator
 from types import ModuleType
 from .jc_types import ParserInfoType, JSONDictType
 from jc import appdirs
+from jc import utils
 
 
-__version__ = '1.24.0'
+__version__ = '1.25.3'
 
 parsers: List[str] = [
     'acpi',
     'airport',
     'airport-s',
+    'apt-cache-show',
+    'apt-get-sqq',
     'arp',
     'asciitable',
     'asciitable-m',
@@ -32,6 +35,7 @@ parsers: List[str] = [
     'crontab-u',
     'csv',
     'csv-s',
+    'curl-head',
     'date',
     'datetime-iso',
     'debconf-show',
@@ -41,8 +45,10 @@ parsers: List[str] = [
     'dmidecode',
     'dpkg-l',
     'du',
+    'efibootmgr',
     'email-address',
     'env',
+    'ethtool',
     'file',
     'find',
     'findmnt',
@@ -61,6 +67,7 @@ parsers: List[str] = [
     'history',
     'host',
     'hosts',
+    'http-headers',
     'id',
     'ifconfig',
     'ini',
@@ -76,6 +83,7 @@ parsers: List[str] = [
     'jobs',
     'jwt',
     'kv',
+    'kv-dup',
     'last',
     'ls',
     'ls-s',
@@ -91,6 +99,7 @@ parsers: List[str] = [
     'mount',
     'mpstat',
     'mpstat-s',
+    'needrestart',
     'netstat',
     'nmcli',
     'nsd-control',
@@ -99,6 +108,8 @@ parsers: List[str] = [
     'os-prober',
     'os-release',
     'passwd',
+    'path',
+    'path-list',
     'pci-ids',
     'pgpass',
     'pidstat',
@@ -241,7 +252,11 @@ def _is_valid_parser_plugin(name: str, local_parsers_dir: str) -> bool:
             if hasattr(plugin, 'info') and hasattr(plugin, 'parse'):
                 del plugin
                 return True
-        except Exception:
+            else:
+                utils.warning_message([f'Not installing invalid parser plugin "{parser_mod_name}" at {local_parsers_dir}'])
+                return False
+        except Exception as e:
+            utils.warning_message([f'Not installing parser plugin "{parser_mod_name}" at {local_parsers_dir} due to error: {e}'])
             return False
     return False
 
@@ -269,13 +284,73 @@ def _parser_argument(parser_mod_name: str) -> str:
     parser = _modname_to_cliname(parser_mod_name)
     return f'--{parser}'
 
+def get_parser(parser_mod_name: Union[str, ModuleType]) -> ModuleType:
+    """
+    Return the parser module object and check that the module is a valid
+    parser module.
+
+    Parameters:
+
+        parser_mod_name:    (string or   Name of the parser module. This
+                            Module)      function will accept module_name,
+                                         cli-name, and --argument-name
+                                         variants of the module name.
+
+                                         If a Module is given and the Module
+                                         is a valid parser Module, then the
+                                         same Module is returned.
+
+    Returns:
+
+        Module:  the parser Module object
+
+    Raises:
+
+        ModuleNotFoundError:  If the Module is not found or is not a valid
+                              parser Module, then a ModuleNotFoundError
+                              exception is raised.
+    """
+    if isinstance(parser_mod_name, ModuleType):
+        jc_parser = parser_mod_name
+    else:
+        try:
+            jc_parser = _get_parser(parser_mod_name)
+        except ModuleNotFoundError:
+            raise ModuleNotFoundError(f'"{parser_mod_name}" is not found or is not a valid parser module.')
+
+    if not hasattr(jc_parser, 'info') or not hasattr(jc_parser, 'parse'):
+        raise ModuleNotFoundError(f'"{jc_parser}" is not a valid parser module.')
+
+    return jc_parser
+
 def _get_parser(parser_mod_name: str) -> ModuleType:
     """Return the parser module object"""
     # ensure parser_mod_name is a true module name and not a cli name
     parser_mod_name = _cliname_to_modname(parser_mod_name)
     parser_cli_name = _modname_to_cliname(parser_mod_name)
     modpath: str = 'jcparsers.' if parser_cli_name in local_parsers else 'jc.parsers.'
-    return importlib.import_module(f'{modpath}{parser_mod_name}')
+    mod = None
+
+    try:
+        mod =  importlib.import_module(f'{modpath}{parser_mod_name}')
+    except Exception as e:
+        mod =  importlib.import_module(f'jc.parsers.disabled_parser')
+        mod.__name__ = parser_mod_name
+        utils.warning_message([f'"{parser_mod_name}" parser disabled due to error: {e}'])
+
+    return mod
+
+def _parser_is_slurpable(parser: ModuleType) -> bool:
+    """
+    Returns True if this parser can use the `--slurp` command option, else False
+
+    parser is a parser module object.
+    """
+    tag_list = getattr(parser.info, 'tags', [])
+    if 'slurpable' in tag_list:
+        return True
+
+    return False
 
 def _parser_is_streaming(parser: ModuleType) -> bool:
     """
@@ -347,15 +422,25 @@ def parse(
     Alternatively, a parser module object can be supplied:
 
         >>> import jc
-        >>> import jc.parsers.date as jc_date
+        >>> jc_date = jc.get_parser('date')
         >>> date_obj = jc.parse(jc_date, 'Tue Jan 18 10:23:07 PST 2022')
         >>> print(f'The year is: {date_obj["year"]}')
         The year is: 2022
 
-    You can also use the lower-level parser modules directly:
+    You can also use the parser modules directly via `get_parser()`:
+
+        >>> import jc
+        >>> jc_date = jc.get_parser('date')
+        >>> date_obj = jc_date.parse('Tue Jan 18 10:23:07 PST 2022')
+        >>> print(f'The year is: {date_obj["year"]}')
+        The year is: 2022
+
+    Finally, you can access the low-level parser modules manually:
 
         >>> import jc.parsers.date
-        >>> jc.parsers.date.parse('Tue Jan 18 10:23:07 PST 2022')
+        >>> date_obj = jc.parsers.date.parse('Tue Jan 18 10:23:07 PST 2022')
+        >>> print(f'The year is: {date_obj["year"]}')
+        The year is: 2022
 
     Though, accessing plugin parsers directly is a bit more cumbersome, so
     this higher-level API is recommended. Here is how you can access plugin
@@ -378,7 +463,7 @@ def parse(
                                          variants of the module name.
 
                                          A Module object can also be passed
-                                         directly or via _get_parser()
+                                         directly or via get_parser()
 
         data:               (string or   data to parse (string or bytes for
                             bytes or     standard parsers, iterable of
@@ -396,10 +481,7 @@ def parse(
         Standard Parsers:   Dictionary or List of Dictionaries
         Streaming Parsers:  Generator Object containing Dictionaries
     """
-    if isinstance(parser_mod_name, ModuleType):
-        jc_parser = parser_mod_name
-    else:
-        jc_parser = _get_parser(parser_mod_name)
+    jc_parser = get_parser(parser_mod_name)
 
     if ignore_exceptions is not None:
         return jc_parser.parse(
@@ -419,7 +501,7 @@ def parser_mod_list(
     """Returns a list of all available parser module names."""
     plist: List[str] = []
     for p in parsers:
-        parser = _get_parser(p)
+        parser = get_parser(p)
 
         if not show_hidden and _parser_is_hidden(parser):
             continue
@@ -441,7 +523,7 @@ def plugin_parser_mod_list(
     """
     plist: List[str] = []
     for p in local_parsers:
-        parser = _get_parser(p)
+        parser = get_parser(p)
 
         if not show_hidden and _parser_is_hidden(parser):
             continue
@@ -464,7 +546,7 @@ def standard_parser_mod_list(
     """
     plist: List[str] = []
     for p in parsers:
-        parser = _get_parser(p)
+        parser = get_parser(p)
 
         if not _parser_is_streaming(parser):
 
@@ -488,7 +570,7 @@ def streaming_parser_mod_list(
     """
     plist: List[str] = []
     for p in parsers:
-        parser = _get_parser(p)
+        parser = get_parser(p)
 
         if _parser_is_streaming(parser):
 
@@ -502,6 +584,30 @@ def streaming_parser_mod_list(
 
     return plist
 
+def slurpable_parser_mod_list(
+    show_hidden: bool = False,
+    show_deprecated: bool = False
+) -> List[str]:
+    """
+    Returns a list of slurpable parser module names. This function is a
+    subset of `parser_mod_list()`.
+    """
+    plist: List[str] = []
+    for p in parsers:
+        parser = get_parser(p)
+
+        if _parser_is_slurpable(parser):
+
+            if not show_hidden and _parser_is_hidden(parser):
+                continue
+
+            if not show_deprecated and _parser_is_deprecated(parser):
+                continue
+
+            plist.append(_cliname_to_modname(p))
+
+    return plist
+
 def parser_info(
     parser_mod_name: Union[str, ModuleType],
     documentation: bool = False
@@ -519,33 +625,26 @@ def parser_info(
 
         documentation:      (boolean)    include parser docstring if True
     """
-    if isinstance(parser_mod_name, ModuleType):
-        parser_mod = parser_mod_name
-        parser_mod_name = parser_mod.__name__.split('.')[-1]
-    else:
-        # ensure parser_mod_name is a true module name and not a cli name
-        parser_mod_name = _cliname_to_modname(parser_mod_name)
-        parser_mod = _get_parser(parser_mod_name)
+    parser_mod = get_parser(parser_mod_name)
+    parser_mod_name = parser_mod.__name__.split('.')[-1]
 
     info_dict: ParserInfoType = {}
+    info_dict['name'] = parser_mod_name
+    info_dict['argument'] = _parser_argument(parser_mod_name)
+    parser_entry = vars(parser_mod.info)
 
-    if hasattr(parser_mod, 'info'):
-        info_dict['name'] = parser_mod_name
-        info_dict['argument'] = _parser_argument(parser_mod_name)
-        parser_entry = vars(parser_mod.info)
+    for k, v in parser_entry.items():
+        if not k.startswith('__'):
+            info_dict[k] = v  # type: ignore
 
-        for k, v in parser_entry.items():
-            if not k.startswith('__'):
-                info_dict[k] = v  # type: ignore
+    if _modname_to_cliname(parser_mod_name) in local_parsers:
+        info_dict['plugin'] = True
 
-        if _modname_to_cliname(parser_mod_name) in local_parsers:
-            info_dict['plugin'] = True
-
-        if documentation:
-            docs = parser_mod.__doc__
-            if not docs:
-                docs = 'No documentation available.\n'
-            info_dict['documentation'] = docs
+    if documentation:
+        docs = parser_mod.__doc__
+        if not docs:
+            docs = 'No documentation available.\n'
+        info_dict['documentation'] = docs
 
     return info_dict
 
@@ -569,7 +668,7 @@ def all_parser_info(
     """
     plist: List[str] = []
     for p in parsers:
-        parser = _get_parser(p)
+        parser = get_parser(p)
 
         if not show_hidden and _parser_is_hidden(parser):
             continue
@@ -577,7 +676,7 @@ def all_parser_info(
         if not show_deprecated and _parser_is_deprecated(parser):
             continue
 
-        plist.append(_cliname_to_modname(p))
+        plist.append(p)
 
     p_info_list: List[ParserInfoType] = [parser_info(p, documentation=documentation) for p in plist]
 
@@ -591,9 +690,5 @@ def get_help(parser_mod_name: Union[str, ModuleType]) -> None:
     **--argument-name** variants of the module name string as well as a
     parser module object.
     """
-    if isinstance(parser_mod_name, ModuleType):
-        jc_parser = parser_mod_name
-    else:
-        jc_parser = _get_parser(parser_mod_name)
-
+    jc_parser = get_parser(parser_mod_name)
     help(jc_parser)
