@@ -1,4 +1,4 @@
-"""jc - JSON Convert IP Address string parser
+r"""jc - JSON Convert IP Address string parser
 
 Accepts standard and integer IP address notation for both IPv4 and IPv6
 addresses. CIDR subnet mask and Scope ID is also allowed for standard
@@ -533,11 +533,12 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.3'
+    version = '1.4'
     description = 'IPv4 and IPv6 Address string parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
     compatible = ['linux', 'darwin', 'cygwin', 'win32', 'aix', 'freebsd']
+    tags = ['standard', 'string', 'slurpable']
 
 
 __version__ = info.version
@@ -560,7 +561,7 @@ def _process(proc_data: Dict) -> Dict:
 
 def _b2a(byte_string: bytes) -> str:
     """Convert a byte string to a colon-delimited hex ascii string"""
-    # need try/except since seperator was only introduced in python 3.8.
+    # need try/except since separator was only introduced in python 3.8.
     # provides compatibility for python 3.6 and 3.7.
     try:
       return binascii.hexlify(byte_string, ':').decode('utf-8')
